@@ -15,19 +15,17 @@ import logging
 import os.path
 import numpy as np
 import matplotlib.pyplot as plt
+import importlib_metadata
 import h5py
 
 from numpy import pi, cos, sin
 from scipy.interpolate import InterpolatedUnivariateSpline
 from packaging.version import Version
-from packaging.specifiers import SpecifierSet
-from lisaconstants import c
+from astropy.coordinates import SkyCoord, BarycentricTrueEcliptic
+from lisaconstants import c, GM_SUN, PARSEC
 
 from .utils import dot, norm, arrayindex, emitter, receiver
 
-from .meta import __version__
-from .meta import __author__
-
 
 logger = logging.getLogger(__name__)
 
@@ -52,7 +50,7 @@ class Response(abc.ABC):
     def __init__(self, orbits, orbit_interp_order=1, dt=0.3, size=259200, t0=0):
 
         self.git_url = 'https://gitlab.in2p3.fr/lisa-simulation/gw-response'
-        self.version = __version__
+        self.version = importlib_metadata.version('lisagwresponse')
         self.classname = self.__class__.__name__
         logger.info("Initializing gravitational-wave response (lisagwresponse verion %s)", self.version)
 
@@ -147,15 +145,13 @@ class Response(abc.ABC):
             # Warn for orbit file development version
             version = Version(orbitf.attrs['version'])
             logger.debug("Using orbit file version %s", version)
-            if version.is_devrelease:
+            if version.is_devrelease or version.local is not None:
                 logger.warning("You are using an orbit file in a development version")
+            if version > Version('2.0'):
+                logger.warning("You are using an orbit file in a version that "
+                               "might not be fully supported")
 
-            if version in SpecifierSet('== 1.*', True):
-                tps = [
-                    interpolate(orbitf['/tps/tau'], orbitf[f'/tps/sc_{sci}'])(tau)
-                    for sci in sc
-                ]
-            elif version in SpecifierSet('== 2.*', True):
+            if version >= Version('2.0.dev'):
                 times = orbitf.attrs['t0'] + np.arange(orbitf.attrs['size']) * orbitf.attrs['dt']
                 orbit_sc = [1, 2, 3]
                 tps = [
@@ -163,7 +159,10 @@ class Response(abc.ABC):
                     for sci in sc
                 ]
             else:
-                raise ValueError(f"unsupported orbit file version '{version}'")
+                tps = [
+                    interpolate(orbitf['/tps/tau'], orbitf[f'/tps/sc_{sci}'])(tau)
+                    for sci in sc
+                ]
 
         return np.stack(tps, axis=-1) # (N, M)
 
@@ -241,10 +240,13 @@ class Response(abc.ABC):
                 version = Version(hdf5.attrs['version'])
                 logger.debug("Using already-existing GW file with version %s", version)
                 # Warn if development version (might create incompatibilities)
-                if version.is_devrelease:
+                if version.is_devrelease or version.local is not None:
                     logger.warning("You are using a GW file in a development version")
+                if version > Version('2.0'):
+                    logger.warning("You are using a GW file in a version that "
+                                   "might not be fully supported")
                 # Only accept to append to a GW of same version
-                if version not in SpecifierSet('== 2.*', True):
+                if version < Version('2.0.dev'):
                     raise ValueError(f"unsupported GW file version '{version}'")
                 # Only accept ``timeframe`` value that matches the file's
                 if timeframe != hdf5.attrs['timeframe']:
@@ -405,15 +407,16 @@ class ResponseFromStrain(Response, abc.ABC):
                     # Warn for orbit file development version
                     version = Version(orbitf.attrs['version'])
                     logger.debug("Using orbit file version %s", version)
-                    if version.is_devrelease:
+                    if version.is_devrelease or version.local is not None:
                         logger.warning("You are using an orbit file in a development version")
+                    if version > Version('2.0'):
+                        logger.warning("You are using an orbit file in a version "
+                                       "that might not be fully supported")
                     # Switch between versions
-                    if version in SpecifierSet('== 1.*', True):
-                        self.t0 = float(orbitf.attrs['tau0'])
-                    elif version in SpecifierSet('== 2.*', True):
+                    if version >= Version('2.0.dev'):
                         self.t0 = float(orbitf.attrs['t0'])
                     else:
-                        raise ValueError(f"unsupported orbit file version '{version}'")
+                        self.t0 = float(orbitf.attrs['tau0'])
 
         # Compute source-localization vector basis
         self.k = np.array([
@@ -453,27 +456,13 @@ class ResponseFromStrain(Response, abc.ABC):
             # Warn for orbit file development version
             version = Version(orbitf.attrs['version'])
             logger.debug("Using orbit file version %s", version)
-            if version.is_devrelease:
+            if version.is_devrelease or version.local is not None:
                 logger.warning("You are using an orbit file in a development version")
+            if version > Version('2.0'):
+                logger.warning("You are using an orbit file in a version "
+                               "that might not be fully supported")
 
-            if version in SpecifierSet('== 1.*', True):
-                self.x = {
-                    sc: interpolate(orbitf['tcb/t'], orbitf[f'tcb/sc_{sc}']['x'])
-                    for sc in self.SC
-                }
-                self.y = {
-                    sc: interpolate(orbitf['tcb/t'], orbitf[f'tcb/sc_{sc}']['y'])
-                    for sc in self.SC
-                }
-                self.z = {
-                    sc: interpolate(orbitf['tcb/t'], orbitf[f'tcb/sc_{sc}']['z'])
-                    for sc in self.SC
-                }
-                self.ltt = {
-                    link: interpolate(orbitf['tcb/t'], orbitf[f'tcb/l_{link}']['tt'])
-                    for link in self.LINKS
-                }
-            elif version in SpecifierSet('== 2.*', True):
+            if version >= Version('2.0.dev'):
                 times = orbitf.attrs['t0'] + np.arange(orbitf.attrs['size']) * orbitf.attrs['dt']
                 self.x = {
                     sc: interpolate(times, orbitf['tcb/x'][:, i, 0])
@@ -492,7 +481,22 @@ class ResponseFromStrain(Response, abc.ABC):
                     for i, link in enumerate(self.LINKS)
                 }
             else:
-                raise ValueError(f"unsupported orbit file version '{version}'")
+                self.x = {
+                    sc: interpolate(orbitf['tcb/t'], orbitf[f'tcb/sc_{sc}']['x'])
+                    for sc in self.SC
+                }
+                self.y = {
+                    sc: interpolate(orbitf['tcb/t'], orbitf[f'tcb/sc_{sc}']['y'])
+                    for sc in self.SC
+                }
+                self.z = {
+                    sc: interpolate(orbitf['tcb/t'], orbitf[f'tcb/sc_{sc}']['z'])
+                    for sc in self.SC
+                }
+                self.ltt = {
+                    link: interpolate(orbitf['tcb/t'], orbitf[f'tcb/l_{link}']['tt'])
+                    for link in self.LINKS
+                }
 
     def _set_orbits(self, x, y, z, ltt):
         """Set orbit data from dictionaries (spacecraft positions and light travel times).
@@ -754,3 +758,53 @@ class GalacticBinary(ResponseFromStrain):
         logger.info("Compute x-polarized gravitational-wave strain in the BCRS")
         hplus_source, hcross_source = self.compute_strain_in_source_frame(t)
         return hplus_source * sin(2 * self.psi) + hcross_source * cos(2 * self.psi)
+
+
+class VerificationBinary(GalacticBinary):
+    """Represent a verification Galactic binary, using dedicated parametrization.
+
+    Args:
+        period (float): system period [s]
+        distance (float): luminosity distance [pc]
+        masses (tuple of floats): 2-tuple of masses [solar mass]
+        glong (float): Galactic longitude [deg]
+        glat (float): Galactic latitude [deg]
+        **kwargs: all other args from :class:`lisagwresponse.GalacticBinary`
+    """
+
+    def _write_metadata(self, hdf5, prefix=''):
+        super()._write_metadata(hdf5, prefix)
+        self._write_attr(
+            hdf5, prefix, 'period', 'distance', 'masses', 'glong', 'glat')
+
+    def __init__(self, period, distance, masses, glong, glat, **kwargs):
+
+        # Save parameters
+        self.period = float(period)
+        self.distance = float(distance)
+        self.masses = (float(masses[0]), float(masses[1]))
+        self.glong = float(glong)
+        self.glat = float(glat)
+
+        # Check that we use Galactic coordinates
+        if ('gw_beta' in kwargs) or ('gw_lambda' in kwargs):
+            raise ValueError("cannot use ecliptic coordinates for verification binary")
+
+        # Convert sky location
+        galactic_coords = SkyCoord(glong, glat, unit='deg', frame='galactic')
+        ecliptic_coords = galactic_coords.transform_to(BarycentricTrueEcliptic())
+        kwargs['gw_beta'] = ecliptic_coords.lat.rad
+        kwargs['gw_lambda'] = ecliptic_coords.lon.rad
+
+        # Compute masses
+        total_mass = (masses[0] + masses[1]) * GM_SUN / c**3
+        reduced_mass = masses[0] * masses[1] / (masses[0] + masses[1])**2
+        chirp_mass = total_mass * reduced_mass**(3/5)
+
+        # Convert parameters
+        f = 2.0 / period # Hz
+        light_dist = distance * PARSEC / c # light-second
+        df = (96/5) * chirp_mass**(5/3) * np.pi**(8/3) * f**(11/3) # Hz / s
+        A = 2 * (total_mass**(5/3) * reduced_mass / light_dist) * (np.pi * f)**(2/3)
+
+        super().__init__(A, f, df, **kwargs)
